function format(text) {
    return text;
}
export const highlightFAIR = (letter, opts) => {
    var _a, _b, _c;
    const l = letter.toLowerCase();
    const color = (_c = (_a = opts === null || opts === void 0 ? void 0 : opts.color) !== null && _a !== void 0 ? _a : (_b = opts === null || opts === void 0 ? void 0 : opts.chalk) === null || _b === void 0 ? void 0 : _b.red) !== null && _c !== void 0 ? _c : format;
    return [
        l.includes('f') ? color('F') : 'F',
        l.includes('a') ? color('A') : 'A',
        l.includes('i') ? color('I') : 'I',
        l.includes('r') ? color('R') : 'R',
    ].join('');
};
export const principleNames = {
    F: 'Findable',
    A: 'Accessible',
    I: 'Interoperable',
    R: 'Reusable',
};
export const principles = {
    F: 'The first step in (re)using data is to find them. Metadata and data should be easy to find for both humans and computers. Machine-readable metadata are essential for automatic discovery of datasets and services, so this is an essential component of the FAIRification process.',
    F1: '(Meta)data are assigned a globally unique and persistent identifier',
    F2: 'Data are described with rich metadata (defined by R1 below)',
    F3: 'Metadata clearly and explicitly include the identifier of the data they describe',
    F4: '(Meta)data are registered or indexed in a searchable resource',
    A: 'Once the user finds the required data, she/he/they need to know how they can be accessed, possibly including authentication and authorisation.',
    A1: '(Meta)data are retrievable by their identifier using a standardised communications protocol',
    A1_1: 'The protocol is open, free, and universally implementable',
    A1_2: 'The protocol allows for an authentication and authorisation procedure, where necessary',
    A2: 'Metadata are accessible, even when the data are no longer available',
    I: 'The data usually need to be integrated with other data. In addition, the data need to interoperate with applications or workflows for analysis, storage, and processing.',
    I1: '(Meta)data use a formal, accessible, shared, and broadly applicable language for knowledge representation.',
    I2: '(Meta)data use vocabularies that follow FAIR principles',
    I3: '(Meta)data include qualified references to other (meta)data',
    R: 'The ultimate goal of FAIR is to optimise the reuse of data. To achieve this, metadata and data should be well-described so that they can be replicated and/or combined in different settings.',
    R1: '(Meta)data are richly described with a plurality of accurate and relevant attributes',
    R1_1: '(Meta)data are released with a clear and accessible data usage license',
    R1_2: '(Meta)data are associated with detailed provenance',
    R1_3: '(Meta)data meet domain-relevant community standards',
};
const principleKeys = Object.keys(principles);
const baseUrl = 'https://www.go-fair.org/fair-principles/';
export function createPrincipleUrl(principle) {
    if (!principle)
        return baseUrl;
    return `${baseUrl}${principle.toLowerCase().replace(/_/g, '-')}`;
}
export function formatPrinciple(principle, opts) {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j;
    const key = principle.replace(/_/g, '.');
    const header = principleNames[principle];
    const colorHeader = (_c = (_a = opts === null || opts === void 0 ? void 0 : opts.header) !== null && _a !== void 0 ? _a : (_b = opts === null || opts === void 0 ? void 0 : opts.chalk) === null || _b === void 0 ? void 0 : _b.bold.cyan) !== null && _c !== void 0 ? _c : format;
    const underline = (_f = (_d = opts === null || opts === void 0 ? void 0 : opts.underlineLetter) !== null && _d !== void 0 ? _d : (_e = opts === null || opts === void 0 ? void 0 : opts.chalk) === null || _e === void 0 ? void 0 : _e.underline) !== null && _f !== void 0 ? _f : format;
    const enuerator = (_j = (_g = opts === null || opts === void 0 ? void 0 : opts.enuerator) !== null && _g !== void 0 ? _g : (_h = opts === null || opts === void 0 ? void 0 : opts.chalk) === null || _h === void 0 ? void 0 : _h.bold.blue) !== null && _j !== void 0 ? _j : format;
    if (header) {
        return [
            colorHeader(`${underline(header.slice(0, 1))}${header.slice(1)}`),
            principles[principle],
        ].join('');
    }
    const indent = principle.includes('_') && (opts === null || opts === void 0 ? void 0 : opts.indent) !== false;
    return `${indent ? '  ' : ''}${enuerator(key)} ${principles[principle]}`;
}
export function formatPrinciples(keys = principleKeys, opts) {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j;
    const ordered = (typeof principleKeys === 'string' ? [] : principleKeys).filter((key) => keys.includes(key) || keys.includes((key.slice(0, 1) + '*')));
    const colorTitle = (_c = (_a = opts === null || opts === void 0 ? void 0 : opts.title) !== null && _a !== void 0 ? _a : (_b = opts === null || opts === void 0 ? void 0 : opts.chalk) === null || _b === void 0 ? void 0 : _b.bold.greenBright) !== null && _c !== void 0 ? _c : format;
    const underline = (_f = (_d = opts === null || opts === void 0 ? void 0 : opts.underlineLetter) !== null && _d !== void 0 ? _d : (_e = opts === null || opts === void 0 ? void 0 : opts.chalk) === null || _e === void 0 ? void 0 : _e.underline) !== null && _f !== void 0 ? _f : format;
    const enuerator = (_j = (_g = opts === null || opts === void 0 ? void 0 : opts.enuerator) !== null && _g !== void 0 ? _g : (_h = opts === null || opts === void 0 ? void 0 : opts.chalk) === null || _h === void 0 ? void 0 : _h.bold.blue) !== null && _j !== void 0 ? _j : format;
    const header = `${colorTitle(`${highlightFAIR(ordered.join(''), { color: underline })} Principle${ordered.length > 1 ? 's' : ''}`)}:`;
    return [header, ...ordered.map((k) => formatPrinciple(k, opts))].join('\n');
}
